#!/usr/bin/ksh
#
# Tektronix Phaser 850
# LPD self-extracting installation script.
#
KIT_COPYRIGHT="Copyright (c) 2003 Hewlett-Packard Company"

KIT_APS=APS
KIT_LPD=LPD
KIT_MINVER="V5.1"
KIT_TYPE=$KIT_LPD
KIT_PRINTER="Tektronix Phaser 850"
KIT_FILES="Tektronix_Phaser_850.lpd tektronix850.rpd"

function setupInstructions {
    mimimumVersionTest V5.1B
    if [[ $? != 0 ]]
    then
	print "Use lprsetup(8) to create an /etc/printcap file entry, specifying" >&2
	print "the printer type "ln17". This creates the entry for your new printer." >&2
	print "Then edit the printcap entry and apply the following changes:" >&2
	print "" >&2
	print "	:if=/usr/lbin/ppdof +OPageSize=Letter +Ctektronix850.rpd:\\" >&2
	print "	:of=/usr/lbin/ppdof +OPageSize=Letter +Ctektronix850.rpd:\\" >&2
	print "	:pw#0:\\" >&2
    else
	print "Use lprsetup(8) to create a new /etc/printcap file entry. Driver" >&2
	print "updates will not impact the current /etc/printcap entries." >&2
    fi
    print "" >&2
    print "For additional information refer to printcap(4) \c" >&2
    if [[ ! -z `find /usr/man/man8/ -name ppdof\*` ]]
    then
	print "and ppdof(8) man pages." >&2
    else
	print "man page." >&2
    fi
}


# Function:
#	askUser Prompt
#
# Description:
#	Prompt for a yes/no response. Default response is no.
#
# Arguments:
#	$1 Prompt Text
#
# Returns:
#	0 User entered yes
#	1 User entered no
#
function askUser {

	print "$1? <Y/N> \c" >&2
	read Response

	case "$Response" in
	[Yy])	return 0
		;;
	[Yy][Ee][Ss])
		return 0
		;;
	*)	return 1
		;;
	esac
}

# Function:
#	wrapMsg Text
#
# Description:
#	Pipe text to fold utility to make sure it will fit
#	within 80 characters.
#
# Arguments:
#	$1 Text, Message Text
#
# Returns:
#	n/a

function wrapMsg {
	print "$1" | fold -s >&2
}

# Function:
#	printLicenseAgreement
#
# Description:
#	Print license agreement
#
# Arguments:
#	None
#
# Returns:
#	Exits when the user does not agree to the terms of the license.

function PrintLicenseAgreement {

    wrapMsg "${KIT_COPYRIGHT}. All rights reserved.\n"

    msg1="                HEWLETT-PACKARD SOFTWARE PRODUCT"
    msg2="                  \"AS IS\" WARRANTY STATEMENT"
    wrapMsg "$msg1\n$msg2\n"

    msg1="DISCLAIMER. TO THE EXTENT ALLOWED BY LOCAL LAW, THIS HP SOFTWARE"
    msg2="PRODUCT (\"SOFTWARE\") IS PROVIDED TO YOU \"AS IS\" WITHOUT WARRANTIES OR"
    msg4="CONDITIONS OF ANY KIND, WHETHER ORAL OR WRITTEN, EXPRESS OR IMPLIED."
    msg5="HP SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTIES OR CONDITIONS OF"
    msg6="MERCHANTABILITY, SATISFACTORY QUALITY, NON-INFRINGEMENT AND FITNESS"
    msg7="FOR A PARTICULAR PURPOSE. Some countries, states and provinces do not"
    msg8="allow exclusions of implied warranties or conditions, so the above"
    msg9="exclusion may not apply to you. You may have other rights that vary"
    msg10="from country to country, state to state, or province to province."
    wrapMsg "$msg1 $msg2 $msg3 $msg4 $msg5 $msg6 $msg7 $msg8 $msg9 $msg10 \n"

    msg1="LIMITATION OF LIABILITY. EXCEPT TO THE EXTENT PROHIBITED BY LOCAL LAW,"
    msg2="IN NO EVENT WILL HP OR ITS SUBSIDIARIES, AFFILIATES OR SUPPLIERS BE"
    msg3="LIABLE FOR DIRECT, SPECIAL, INCIDENTAL, CONSEQUENTIAL OR OTHER DAMAGES"
    msg4="(INCLUDING LOST PROFIT, LOST DATA, OR DOWNTIME COSTS), ARISING OUT OF"
    msg5="THE USE, INABILITY TO USE, OR THE RESULTS OF USE OF THE SOFTWARE,"
    msg6="WHETHER BASED IN WARRANTY, CONTRACT, TORT OR OTHER LEGAL THEORY, AND"
    msg7="WHETHER OR NOT ADVISED OF THE POSSIBILITY OF SUCH DAMAGES. Your use of"
    msg8="the Software is entirely at your own risk. Should the Software prove"
    msg9="defective, you assume the entire cost of all service, repair or"
    msg10="correction. Some countries, states and provinces do not allow the"
    msg11="exclusion or limitation of liability for incidental or consequential"
    msg12="damages, so the above limitation may not apply to you."
    wrapMsg "$msg1 $msg2 $msg3 $msg4 $msg5 $msg6 $msg7 $msg8 $msg9 $msg10 $msg11 $msg12 \n"

    msg1="NOTE. EXCEPT TO THE EXTENT ALLOWED BY LOCAL LAW, THESE WARRANTY TERMS"
    msg2="DO NOT EXCLUDE, RESTRICT OR MODIFY, AND ARE IN ADDITION TO, THE"
    msg3="MANDATORY STATUTORY RIGHTS APPLICABLE TO THE LICENSE OF THE SOFTWARE"
    msg4="TO YOU."
    wrapMsg "$msg1 $msg2 $msg3 $msg4 \n"

}

# Function:
#	fileVersionTest Version PathFilename
#
# Description:
#	Fetch and compare the file version.
#
# Arguments:
#	$1 Version, The version of the file in this script
#	$2 PathFilename, path/filename of file to test
#
# Returns:
#	0 Script file older than installed file
#	1 Script file the same as installed file
#	2 Script file newier than install file
#
function fileVersionTest {

	new_ver=$(fixVersion $1)

	base=$(basename $2)
	ext=$(basename $2 | cut -f2 -d'.')
	case $ext in
	lpd)
		# Version format: 1.1.2.4
		old_ver=$(grep 'Revision:' $2 | cut -f4 -d\$ | cut -f2 -d: )
		;;
	paf)
		# Version format: APX-1-001 or 100
		old_ver=$(grep 'paf-x-file-version' $2 | cut -f2 -d\= )
		;;
	pcf)
		# Version format: 1.1.2.4
		old_ver=$(grep 'Revision:' $2 | cut -f4 -d\$ | cut -f2 -d: )
		;;
	pfo)
		# The version is not provided in all the files.
		# Version format: 1.0
		old_ver=$(grep 'FileVersion' $2 | cut -f2 -d\: )
		[[ -z $old_ver ]] && old_ver="0.0"
		;;
	[rp]pd)
		# Version format: "1.0"
		old_ver=$(grep '\*FileVersion' $2 | cut -f2 -d\: )
		;;
	*)
		# Lpd print filter?
		old_ver=$(what $2 | tr -s '@' '\n' | grep $base | grep 'Revision:' | cut -f4 -d\$ | cut -f2 -d: )
		;;
	esac

	old_ver=$(fixVersion $old_ver)

	# Are the versions the same?
	if [[ $new_ver = $old_ver ]] 
	then	# Yes
		return 1
	fi

	if [[ $new_ver > $old_ver ]]
	then
		# New file more current
		return 2
	else
		# System file more current
		return 0
	fi
}

# Function:
#	checkSumTest PathFilename CheckSum1 CheckSum2
#
# Description:
#	Fetch and compare the file version.
#
# Arguments:
#	$1 PathFilename, path/filename
#	$2 CheckSum1,  First checksum value generated from the 'sum' command.
#	$3 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Checksum matched
#	1 Checksum error
#
function checkSumTest {

	sum1=`sum $1 | tr -s "  " " " | cut -f 1 -d ' '`
	sum2=`sum $1 | tr -s "  " " " | cut -f 2 -d ' '`

	if [[ $sum1 -ne $2 ]] || [[ $sum2 -ne $3 ]]
	then
		return 1
	else
		return 0
	fi
}

# Function:
#	installTest FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	Test to see if the directory exists and the file
#	uuencoded file is newier than the system file.
#
# Arguments:
#	$1 FileVersion,  File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Install file, all tests passed
#	1 Don't install file, one or more tests failed
function installTest {
	mkdir=0

	# Can't install the file if the directory doesn't exist.

	file_name=`basename $2`
	directory=`dirname $2`

	if [[ ! -d $directory ]]
	then
		if [[ $mkdir = 0 ]]
		then
			msg1="Error: File $file_name not installed because"
			msg2="directory $directory doesn't exist."
			wrapMsg "$msg1 $msg2"
			return 1
		else
			mkdir $directory
			chmod 755 $directory
			chown root:system $directory
		fi
	fi

	# If the file does not exist, it's ok to install.
	if [[ ! -e $2 ]]
	then
		return 0
	fi

	fileVersionTest $1 $2
	status=$?

	if [[ $status = 1 ]]
	then
		checkSumTest $2 $3 $4
		if [[ $? = 0 ]]
		then
			# Files are the same, don't install
			wrapMsg "The $file_name system file is current and will not be replaced.\n"
			return 1
		else
			# Versions are the same, but the files are different!
			print "Warning: File versions match but the files are different!">&2
			askUser "Replace $file_name"
			return $?
		fi
	fi

	if [[ $status = 0 ]]
	then
		wrapMsg "The $file_name system file is newier and will not be replaced.\n"
		return 1
 	fi

	return 0
}

# Function:
#	mimimumVersionTest version
#
# Description:
#	Test to see if the minimum application or operating version 
#	requirement is met.
#
# Arguments:
#	$1 Version,    Minimum install version requirement
#
# Returns:
#	0 test passed
#	1 test failed
#
function mimimumVersionTest {

	if [[ $KIT_TYPE = $KIT_APS ]]
	then
		# At this time there isn't a minimum APS requirement.
		return 0 
	fi

	# The only other kit type is LPD, so check the OS version.

	# Note: The version field moves 1 position between Digital UNIX
	#       and Compaq Tru64 UNIX, but is always before (Rev.
	temp=` strings /vmunix | grep '(Rev.' | grep UNIX | cut -f1 -d '(' `

	# The version is the last value
	for x in $temp
	{
	  osver=$x
	}

	# A field test version of the OS might not start with a V. At some
	# point we might need to note the difference, but for now we don't.
	# Modify the version string by replacing the first character with a V.

	temp=$osver
	osver="V$( echo "$osver" | cut -c2- )"

	if [[ $osver < $1 ]]
	then
		return 1
	fi

	return 0
}

# Function:
#	installLpdTest FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	If the file does not currently exist and the minimal install
#	requirements are met, a success status is returned.
#
# Arguments:
#	$1 FileVersion,  File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Exits:
#	Exit if the minimum OS requirement is not met.
#
# Returns:
#	0 Install file, all tests passed
#	1 Don't install file, one or more tests failed
#
function installLpdTest {

	file_name=`basename $2`
	file_ext=`print "$file_name" | cut -f2 -d'.'`

	# Perform the OS test after this test. No reason to complain
	# about the os version if the file isn't going to be installed.
	if [[ $file_ext = "lpd" ]]
	then
		# If this is a .lpd file and the base directory doesn't exist
		# return.
		if [[ ! -d `dirname $2` ]]
		then
			msg1="File $file_name is not required for this version of Tru64 UNIX.\n"
			wrapMsg "$msg1"
			return 1
		fi
	fi

	installTest $1 $2 $3 $4
	return $?
}


# Function:
#	installApsTest FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	Test the minimal install requirements for an APS file. 
#
# Arguments:
#	$1 File version, File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Install file, all tests passed
#	1 Don't install file, one or more tests failed
#

function installApsTest {

	installTest $1 $2 $3 $4
	return $?
}

# Function:
#	fixVersion Version
#
# Description:
#	Remove unwanted characters.
#	Aps two version formats are converted to a common format.
#
# Arguments:
#	$1 Version, Version string
#
# Returns:
#	The updated version string.
#
function fixVersion {

	# Remove quotes, tabs, and spaces
	ver=$(echo $1 | tr -d "\"\t ")

	# Set null strings to version 0
	if [[ -z $ver ]]
	then
		ver=0
	fi

	# If the version starts with 'a', convert
	# a???-x-xxx to xxxx
	case $ver in
	[Aa]*)	;;
	[0123456789]*)
		# Return the version
		print "$ver"
		return
		;;
	*)	# Don't know what we found so return a version of 0.
		print "0.0"
		;;
	esac

	# To compare version 100 to apx-?-??? convert
	# apx-1-001 to 1001
	# apx-1-2   to 1002
	part1=$(echo "$ver" | cut -f2 -d\-)
	part2=$(echo "$ver" | cut -f3 -d\-)

	ver=$(printf "%s%.3d" $part1 $part2)

	# Return the version
	print "$ver"
	return
}

# Function:
#	preInstall FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	Determine if this is an APS or LPD install and call the
#	appropriate function.
#
# Arguments:
#	$1 FileVersion,  File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Install file
#	1 Don't install file
#
function preInstall {

	status=1

	if [[ $KIT_TYPE = $KIT_LPD ]] 
	then
		installLpdTest $1 $2 $3 $4
		status=$?
	fi

	if [[ $KIT_TYPE = $KIT_APS ]] 
	then
		installApsTest $1 $2 $3 $4
		status=$?
	fi

	# On install status, backup existing file
	# if it exists
	if [[ $status = 0 ]]
	then
		if [[ -e $2 ]]
		then
			# format = filename_yyyymmmdd_hh:mm:ss
			backup=$2_$(date +"b%d_%T")
			mv $2 $backup
			wrapMsg "Backup file $backup created."

			# Return the name of the backup file
			print "$backup"
		fi
	fi
	return $status
}

# Function:
#	postInstall BackupFile Owner Group Protection FileName CheckSum1 CheckSum2
#
# Description:
#	After the file has been installed verify the file checksum. If
#	the checksum is ok, set the file owner and protection.
#
#	Notify the user of a checksum error and prompt to remove the file.
#
# Arguments:
#	$1 BackupFile, Name of the backup file
#	$2 Owner,      File owner for chown command
#	$3 Group,      Group owner for chgrp command
#	$4 Protection, File protections number, eg 644, for chmod command
#	$5 FileName,   Installed file path/filename
#	$6 CheckSum1,  First checksum value generated from the 'sum' command.
#	$7 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	None
#
function postInstall {

	chown $2:$3 $5
	chmod $4 $5

	checkSumTest $5 $6 $7
	if [[ $? != 0 ]]
	then
		wrapMsg "Install checksum error on file $5!"

		if [[ ! -z $1 ]]
		then
			askUser "Restore the backup file"
		else
			askUser "Delete the file $5"
		fi

		if [[ $? = 0 ]]
		then 
			rm $5
			if [[ ! -z $1 ]]
			then
				mv $1 $5
				wrapMsg "Backup file restored.\n"
			else
				wrapMsg "File $5 deleted.\n"
			fi
		fi
	else
		wrapMsg "File $5 installed.\n"
		FileInstalled=1
	fi
	return
}

# Function:
#	doHelp
#
# Description:
#	Display the install script options.
#
# Arguments:
#	None
#
# Returns:
#	None
#
function doHelp {
	print "Synopsis: $(basename $0) -option" >&2
	print "" >&2
	print "Options:  -i Install files" >&2
	print "          -p Printer configuration instructions" >&2
	print "" >&2
	return
}

#
# Program
#

typeset -xi FileInstalled=0

# Identify the program

if [[ $KIT_TYPE = $KIT_LPD ]]
then
	print "LPD \c"

elif [[ $KIT_TYPE = $KIT_APS ]]
then
	print "Advanced Printing Software \c"
fi

print "installation kit for: $KIT_PRINTER\n"


# When no arguments are provided, display the help text and exit.
if [[  $# = 0 ]]
then
	doHelp
	exit 0
fi

while getopts :hip opt
do
        case $opt in
	h)	doHelp
		exit 0
		;;
	i)	# Install, fall out of case statement
		;;
	p)	# Print post-install setup instructions
		setupInstructions
		exit 0
		;;
	\?)	doHelp
		exit 0
                ;;
        esac
done

UserName=`whoami`

if [[ $UserName != "root" ]]
then
	print "You must be root to run this program."
	exit 1
fi

mimimumVersionTest $KIT_MINVER
if [[ $? != 0 ]]
then
	msg1="This installation requires a minimum"
	msg2="operating system version of $1."
	wrapMsg "$msg1 $msg2"
	exit 1
fi

subset_name=UNKNOWN
if [[ $KIT_TYPE = $KIT_LPD ]]
then
	subset_name=OSFPRINT
elif [[ $KIT_TYPE = $KIT_APS ]]
then
	subset_name=APXBASE
else
	print "Error: Unknown kit type."
	exit 1
fi

if [ ! -e /usr/.smdb./$subset_name*.lk ]
then
	print "The update requires the $subset_name subset to be installed."
	exit 1
fi

print "This kit contains the following files:\n"

echo "$KIT_FILES" | fold -s
print ""

PRESS_ENTER='Press ENTER to continue'

printf "$PRESS_ENTER"
read temp

PrintLicenseAgreement 2>&1 | pg -e -p "$PRESS_ENTER" >&2

askUser "Do you accept the terms in the license agreement"
if [[ $? != 0 ]]
then
	# User did not accept license agreement.
	print "No files were installed."
	exit 1
fi
print "\n\n"

#--- uuencoded files ---
backup_file=$(preInstall "1.1.4.1" /usr/lbin/lprsetup/Tektronix_Phaser_850.lpd 56491 1)
if [[ $? = 0 ]]
then
uudecode << 'EndOfEncodedFile'
begin 644 /usr/lbin/lprsetup/Tektronix_Phaser_850.lpd
M(R!`*",I)%)#4V9I;&4Z(%1E:W1R;VYI>%]0:&%S97)?.#4P+FQP9"QV("0@
M)%)E=FES:6]N.B`Q+C$N-"XQ("0@)$1A=&4Z(#(P,#$O,#DO,3<@,30Z,#8Z
M,3<@)`IP<FEN=&5R.EP*("`@(#I03CU496MT<F]N:7@@4&AA<V5R(#@U,#I<
M"B`@("`Z8G(].38P,#I<"B`@("`Z9F,],#$W-S<W-SI<"B`@("`Z9G,],#,Z
M7`H@("`@.FEF/2]U<W(O;&)I;B]P<&1O9B`K3U!A9V53:7IE/4QE='1E<B`K
M0W1E:W1R;VYI>#@U,"YR<&0Z7`H@("`@.F]F/2]U<W(O;&)I;B]P<&1O9B`K
M3U!A9V53:7IE/4QE='1E<B`K0W1E:W1R;VYI>#@U,"YR<&0Z7`H@("`@.GAF
M/2]U<W(O;&)I;B]X9CI<"B`@("`Z;7@],#I<"B`@("`Z<&P]-C8Z7`H@("`@
M.G!W/3`Z7`H@("`@.G)W/6]N.EP*("`@(#IX8STP,3<W-S<W.EP*("`@(#IX
M<STP-#0P,#`Z7`H@("`@.E!$/5QN7`I4:&4@6&5R;W@@5&5K=')O;FEX(%!H
M87-E<B`X-3`@:7,@82`Q-"!P<&T@8V]L;W(@4$-,(&%N9"!0;W-T4V-R:7!T
:7&Y<"FQA<V5R('!R:6YT97(N7`I<;EQN.@H@
`
end
EndOfEncodedFile
postInstall "$backup_file" bin bin 644 /usr/lbin/lprsetup/Tektronix_Phaser_850.lpd 56491 1
fi

backup_file=$(preInstall "1.0" /usr/lbin/ppd/tektronix850.rpd 63749 5)
if [[ $? = 0 ]]
then
uudecode << 'EndOfEncodedFile'
begin 644 /usr/lbin/ppd/tektronix850.rpd
M*D9I;&5697)S:6]N.B`B,2XP(@HJ4')O9'5C=#H@(BA0:&%S97(@.#4P1%`I
M(@HJ36]D96Q.86UE.B`B5&5K=')O;FEX(%!H87-E<B`X-3`B"BI04U9E<G-I
M;VXZ("(H,S`Q,"XQ,#@I(#DB"BI,86YG=6%G94QE=F5L.B`B,R(**E!#1FEL
M94YA;64Z(")T96MT<F]N:7@X-3`N<G!D(@HJ3W)D97)$97!E;F1E;F-Y.B`U
M-"!!;GE3971U<"`J1'5P;&5X"BI$=7!L97@@1'5P;&5X3F]4=6UB;&4O1'5P
M;&5X.B`B/#PO1'5P;&5X('1R=64@("]4=6UB;&4@9F%L<V4^/B!S971P86=E
M9&5V:6-E(@HJ1'5P;&5X($1U<&QE>%1U;6)L92]$=7!L97@@5'5M8FQE.B`B
M/#PO1'5P;&5X('1R=64@("]4=6UB;&4@=')U93X^('-E='!A9V5D979I8V4B
M"BI$=7!L97@@3F]N92]3:6UP;&5X.B`B/#PO1'5P;&5X(&9A;'-E("]4=6UB
M;&4@9F%L<V4^/B!S971P86=E9&5V:6-E(@HJ3W)D97)$97!E;F1E;F-Y.B`U
M."!!;GE3971U<"`J4&%G95-I>F4**E!A9V53:7IE($$T+T$T(#(Q,"!X(#(Y
M-R!M;3H@(CP\("]086=E4VEZ92!;-3DU(#@T,ET@+TEM86=I;F="0F]X(&YU
M;&P@/CX@<V5T<&%G961E=FEC92(**E!A9V53:7IE($QE='1E<B],971T97(@
M."`Q+S(@>"`Q,2!I;CH@(CP\("]086=E4VEZ92!;-C$R(#<Y,ET@+TEM86=I
M;F="0F]X(&YU;&P@/CX@<V5T<&%G961E=FEC92(**E!A<&5R1&EM96YS:6]N
M($$T.B`B-3DU(#@T,B(**E!A<&5R1&EM96YS:6]N($QE='1E<CH@(C8Q,B`W
M.3(B"BI);6%G96%B;&5!<F5A($$T.B`B,30N,S(@,30N,3,@-3DW+CDV(#<W
M."XQ."(**DEM86=E86)L94%R96$@3&5T=&5R.B`B,30N,S$@,30N,3,@-3DW
M+CDV(#<W."XQ-R(**D]R9&5R1&5P96YD96YC>3H@-#`@06YY4V5T=7`@*DEN
M<'5T4VQO=`HJ26YP=713;&]T(&UA;G5A;"]-=6QT:2U0=7)P;W-E(%1R87DZ
M("(\/"`O36%N=6%L1F5E9"!T<G5E(#X^('-E='!A9V5D979I8V4B"BI);G!U
M=%-L;W0@=')A>3$O57!P97(@5')A>3H@(CP\("]-961I85!O<VET:6]N(#`@
M+TUE9&EA0VQA<W,@;G5L;`H@("`@+U1R87E3=VET8V@@9F%L<V4@+TUA;G5A
M;$9E960@9F%L<V4@/CX@<V5T<&%G961E=FEC92(**DEN<'5T4VQO="!T<F%Y
M,B]-:61D;&4@5')A>3H@(CP\("]-961I85!O<VET:6]N(&-U<G)E;G1P86=E
M9&5V:6-E"B`@("`O26YP=71!='1R:6)U=&5S(&=E="!D=7`@,B!K;F]W;B![
M<&]P(#%]('LQ(&MN;W=N('LQ?2![,'T@:69E;'-E?2!I9F5L<V4*("`@("]-
M961I84-L87-S(&YU;&P@+U1R87E3=VET8V@@9F%L<V4@+TUA;G5A;$9E960@
M9F%L<V4@/CX@<V5T<&%G961E=FEC92(**DEN<'5T4VQO="!T<F%Y,R],;W=E
M<B!4<F%Y.B`B/#P@+TUE9&EA4&]S:71I;VX@8W5R<F5N='!A9V5D979I8V4*
M("`@("]);G!U=$%T=')I8G5T97,@9V5T(&1U<"`R(&MN;W=N('MP;W`@,GT@
M>S$@:VYO=VX@>S%]('LP?2!I9F5L<V5](&EF96QS90H@("`@+TUE9&EA0VQA
M<W,@;G5L;"`O5')A>5-W:71C:"!F86QS92`O36%N=6%L1F5E9"!F86QS92`^
M/B!S971P86=E9&5V:6-E(@HJ3W)D97)$97!E;F1E;F-Y.B`T-2!!;GE3971U
M<"`J365D:6%4>7!E"BI-961I851Y<&4@4&%P97(Z("(\/"]-961I85!O<VET
M:6]N(&YU;&P@+TUE9&EA0VQA<W,@*%!A<&5R*0H@("`@+U1R87E3=VET8V@@
M=')U92`O36%N=6%L1F5E9"!F86QS92`^/B!S971P86=E9&5V:6-E(@HJ365D
M:6%4>7!E(%1R86YS<&%R96YC>3H@(CP\+TUE9&EA4&]S:71I;VX@;G5L;"`O
M365D:6%#;&%S<R`H5')A;G-P87)E;F-Y*0H@("`@+U1R87E3=VET8V@@=')U
M92`O36%N=6%L1F5E9"!F86QS92`^/B!S971P86=E9&5V:6-E(@HJ1F]N="!!
M<FEA;"U";VQD271A;&EC350Z("(B"BI&;VYT($%R:6%L+4)O;&1-5#H@(B(*
M*D9O;G0@07)I86PM271A;&EC350Z("(B"BI&;VYT($%R:6%L0T4Z("(B"BI&
M;VYT($%R:6%L0T4M0F]L9#H@(B(**D9O;G0@07)I86Q#12U";VQD271A;&EC
M.B`B(@HJ1F]N="!!<FEA;$-%+4ET86QI8SH@(B(**D9O;G0@07)I86Q-5#H@
M(B(**D9O;G0@079A;G1'87)D92U";V]K.B`B(@HJ1F]N="!!=F%N=$=A<F1E
M+4)O;VM/8FQI<75E.B`B(@HJ1F]N="!!=F%N=$=A<F1E+41E;6DZ("(B"BI&
M;VYT($%V86YT1V%R9&4M1&5M:4]B;&EQ=64Z("(B"BI&;VYT($%V86YT1V%R
M9&5#12U";V]K.B`B(@HJ1F]N="!!=F%N=$=A<F1E0T4M0F]O:T]B;&EQ=64Z
M("(B"BI&;VYT($%V86YT1V%R9&5#12U$96UI.B`B(@HJ1F]N="!!=F%N=$=A
M<F1E0T4M1&5M:4]B;&EQ=64Z("(B"BI&;VYT($-O=7)I97(Z("(B"BI&;VYT
M($-O=7)I97(M0F]L9#H@(B(**D9O;G0@0V]U<FEE<BU";VQD3V)L:7%U93H@
M(B(**D9O;G0@0V]U<FEE<BU/8FQI<75E.B`B(@HJ1F]N="!#;W5R:65R0T4Z
M("(B"BI&;VYT($-O=7)I97)#12U";VQD.B`B(@HJ1F]N="!#;W5R:65R0T4M
M0F]L9$]B;&EQ=64Z("(B"BI&;VYT($-O=7)I97)#12U/8FQI<75E.B`B(@HJ
M1F]N="!(96QV971I8V$Z("(B"BI&;VYT($AE;'9E=&EC82U";VQD.B`B(@HJ
M1F]N="!(96QV971I8V$M0F]L9$]B;&EQ=64Z("(B"BI&;VYT($AE;'9E=&EC
M82U#;VYD96YS960Z("(B"BI&;VYT($AE;'9E=&EC82U#;VYD96YS960M0F]L
M9#H@(B(**D9O;G0@2&5L=F5T:6-A+4-O;F1E;G-E9"U";VQD3V)L.B`B(@HJ
M1F]N="!(96QV971I8V$M0V]N9&5N<V5D+4]B;&EQ=64Z("(B"BI&;VYT($AE
M;'9E=&EC82U.87)R;W<Z("(B"BI&;VYT($AE;'9E=&EC82U.87)R;W<M0F]L
M9#H@(B(**D9O;G0@2&5L=F5T:6-A+4YA<G)O=RU";VQD3V)L:7%U93H@(B(*
M*D9O;G0@2&5L=F5T:6-A+4YA<G)O=RU/8FQI<75E.B`B(@HJ1F]N="!(96QV
M971I8V$M3V)L:7%U93H@(B(**D9O;G0@2&5L=F5T:6-A0T4Z("(B"BI&;VYT
M($AE;'9E=&EC84-%+4)O;&0Z("(B"BI&;VYT($AE;'9E=&EC84-%+4)O;&1/
M8FQI<75E.B`B(@HJ1F]N="!(96QV971I8V%#12U#;VYD.B`B(@HJ1F]N="!(
M96QV971I8V%#12U#;VYD0F]L9#H@(B(**D9O;G0@2&5L=F5T:6-A0T4M0V]N
M9$)O;&1/8FPZ("(B"BI&;VYT($AE;'9E=&EC84-%+4-O;F1/8FPZ("(B"BI&
M;VYT($AE;'9E=&EC84-%+4YA<G)O=SH@(B(**D9O;G0@2&5L=F5T:6-A0T4M
M3F%R<F]W0F]L9#H@(B(**D9O;G0@2&5L=F5T:6-A0T4M3F%R<F]W0F]L9$]B
M;&EQ=64Z("(B"BI&;VYT($AE;'9E=&EC84-%+4YA<G)O=T]B;&EQ=64Z("(B
M"BI&;VYT($AE;'9E=&EC84-%+4]B;&EQ=64Z("(B"BI&;VYT($YE=T-E;G1U
M<GE38VAL8FLM0F]L9#H@(B(**D9O;G0@3F5W0V5N='5R>5-C:&QB:RU";VQD
M271A;&EC.B`B(@HJ1F]N="!.97=#96YT=7)Y4V-H;&)K+4ET86QI8SH@(B(*
M*D9O;G0@3F5W0V5N='5R>5-C:&QB:RU2;VUA;CH@(B(**D9O;G0@3F5W0V5N
M='5R>5-C:&QB:T-%+4)O;&0Z("(B"BI&;VYT($YE=T-E;G1U<GE38VAL8FM#
M12U";VQD271A;&EC.B`B(@HJ1F]N="!.97=#96YT=7)Y4V-H;&)K0T4M271A
M;&EC.B`B(@HJ1F]N="!.97=#96YT=7)Y4V-H;&)K0T4M4F]M86XZ("(B"BI&
M;VYT(%1I;65S+4)O;&0Z("(B"BI&;VYT(%1I;65S+4)O;&1)=&%L:6,Z("(B
M"BI&;VYT(%1I;65S+4ET86QI8SH@(B(**D9O;G0@5&EM97,M4F]M86XZ("(B
M"BI&;VYT(%1I;65S0T4M0F]L9#H@(B(**D9O;G0@5&EM97-#12U";VQD271A
M;&EC.B`B(@HJ1F]N="!4:6UE<T-%+4ET86QI8SH@(B(**D9O;G0@5&EM97-#
M12U2;VUA;CH@(B(**D9O;G0@5&EM97-.97=2;VUA;D-%.B`B(@HJ1F]N="!4
M:6UE<TYE=U)O;6%N0T4M0F]L9#H@(B(**D9O;G0@5&EM97-.97=2;VUA;D-%
M+4)O;&1)=&%L:6,Z("(B"BI&;VYT(%1I;65S3F5W4F]M86Y#12U)=&%L:6,Z
M("(B"BI&;VYT(%1I;65S3F5W4F]M86Y04RU";VQD271A;&EC350Z("(B"BI&
M;VYT(%1I;65S3F5W4F]M86Y04RU";VQD350Z("(B"BI&;VYT(%1I;65S3F5W
M4F]M86Y04RU)=&%L:6--5#H@(B(**D9O;G0@5&EM97-.97=2;VUA;E!3350Z
M("(B"BI&;VYT($5U<F]S=&EL93H@(B(**D9O;G0@175R;W-T:6QE+4)O;&0Z
M("(B"BI&;VYT($5U<F]S=&EL92U";VQD17AT96YD9614=V\Z("(B"BI&;VYT
M($5U<F]S=&EL92U%>'1E;F1E9%1W;SH@(B(**D9O;G0@175R;W-T:6QE0T4Z
M("(B"BI&;VYT($5U<F]S=&EL94-%+4)O;&0Z("(B"BI&;VYT($5U<F]S=&EL
M94-%+4)O;&1%>'1E;F1E9%1W;SH@(B(**D9O;G0@175R;W-T:6QE0T4M17AT
-96YD9614=V\Z("(B"F1E
`
end
EndOfEncodedFile
postInstall "$backup_file" bin bin 644 /usr/lbin/ppd/tektronix850.rpd 63749 5
fi

mimimumVersionTest V5.1B
if [[ $? = 0 ]] && [[ $FileInstalled > 0 ]]
then
    if [[ -z $(/usr/sbin/lprsetup -c update) ]]
    then
        print "File /etc/lprsetup.dat was backed up then updated."
    fi
fi
exit 0
